ParseWrapper

Struct ParseWrapper 

pub struct ParseWrapper<P: Parse>(/* private fields */);
A wrapper around syn’s Parse trait that implements Deserialize in the context of from_tokenstream.

This extends TokenStreamWrapper by further interpreting the TokenStream and guiding the user in the case of parse errors.

Panics

The Deserialize implementation for TokenStreamWrapper will panic if it is not used in the context of from_tokenstream.

Implementations

Source

impl<P: Parse> ParseWrapper<P>

pub fn into_inner(self) -> P